@@ -1,7 +1,7 @@
 package POE::Component::IKC::ClientLite;
 
 ############################################################
-# $Id: ClientLite.pm,v 1.12 2001/08/02 03:26:50 fil Exp $
+# $Id: ClientLite.pm,v 1.13 2001/09/06 23:13:42 fil Exp $
 # By Philp Gwyn <fil@pied.nu>
 #
 # Copyright 1999 Philip Gwyn.  All rights reserved.
@@ -617,6 +617,10 @@ L<POE>, L<POE::Component::IKC>
 
 
 $Log: ClientLite.pm,v $
+Revision 1.13  2001/09/06 23:13:42  fil
+Added doco for Responder->spawn
+Responder->spawn always returns true so that JAAS's factory doesn't complain
+
 Revision 1.12  2001/08/02 03:26:50  fil
 Added documentation.
 
