@@ -1,8 +1,8 @@
-# $Id: Proxy.pm,v 1.6 2001/07/24 20:45:54 fil Exp $
+# $Id: Proxy.pm,v 1.7 2001/09/06 23:13:42 fil Exp $
 package POE::Component::IKC::Proxy;
 
 ##############################################################################
-# $Id: Proxy.pm,v 1.6 2001/07/24 20:45:54 fil Exp $
+# $Id: Proxy.pm,v 1.7 2001/09/06 23:13:42 fil Exp $
 # Copyright 1999 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -151,6 +151,10 @@ L<POE>, L<POE::Component::IKC>
 
 
 $Log: Proxy.pm,v $
+Revision 1.7  2001/09/06 23:13:42  fil
+Added doco for Responder->spawn
+Responder->spawn always returns true so that JAAS's factory doesn't complain
+
 Revision 1.6  2001/07/24 20:45:54  fil
 Fixed some win32 things like WSAEAFNOSUPPORT
 Added more tests to t/20_clientlite.t
