@@ -1,7 +1,7 @@
 package POE::Component::IKC::Responder;
 
 ############################################################
-# $Id: Responder.pm,v 1.11 2001/08/02 03:26:50 fil Exp $
+# $Id: Responder.pm,v 1.13 2001/10/27 03:14:45 fil Exp $
 # Based on tests/refserver.perl
 # Contributed by Artur Bergman <artur@vogon-solutions.com>
 # Revised for 0.06 by Rocco Caputo <troc@netrus.net>
@@ -41,7 +41,7 @@ sub create_ikc_responder
 sub spawn
 {
     my($package)=@_;
-    return if $ikc;
+    return 1 if $ikc;
     new POE::Session( $package, [qw(
                       _start _stop
                       request post call raw_message post2
@@ -52,6 +52,7 @@ sub spawn
                       monitor shutdown 
                       do_you_have ping sig_INT
                     )]);
+    return 1;
 }
 
 
@@ -880,21 +881,22 @@ sub call
 sub publish
 {
     my($self, $session, $states)=@_;
-
     if(ref $session) {                  # make sure it's not an object
         my $kernel=$self->{poe_kernel};
         if($kernel->can('alias_list')) {
-            # post 0.15 we register as all aliases for session
+            my $has_aliases=0;
+
+            # post-0.15 we register as all aliases for session
             foreach my $alias ($kernel->alias_list($session->ID)) {
                 $self->publish($alias, $states);
+                $has_aliases=1;
             }
-            return;
+            return if $has_aliases;
         } 
-        else {
-            # pre 0.15 means that we register as session ID... which is less
-            # then useful
-            $session=$session->ID;
-        }
+
+        # pre-0.15 means that we register as session ID... which is less
+        # then useful
+        $session=$session->ID;
     }
     unless($session) {
         carp "You must specify the session that publishes these states";
@@ -962,7 +964,7 @@ sub retract
     }
 
     unless($self->{'local'}{$sid}) {
-        warn "Session '$session' ($sid) didn't publish anything";
+        warn "Session '$session' ($sid) didn't publish anything, can't retract";
         return 0;
     }
 
@@ -1383,6 +1385,15 @@ better behaved, because POE is a cooperative system.
 
 =head1 STATES/METHODS
 
+=head2 C<spawn>
+
+    POE::Component::IKC::Responder->spawn();
+
+This function creates the Responder session and object.  Normally, 
+C<IKC::Client> or C<IKC::Server> does this for you.  But in some applications
+you want to make sure that the Responder is up and running before then.
+
+
 =head2 C<post>
 
 Sends an state request to a foreign kernel.  Returns logical true if the
@@ -1913,5 +1924,12 @@ L<POE>, L<POE::Component::IKC::Server>, L<POE::Component::IKC::Client>
 
 
 $Log: Responder.pm,v $
+Revision 1.13  2001/10/27 03:14:45  fil
+Now works with latest CVS version of POE (0.1701)
+
+Revision 1.12  2001/09/06 23:13:42  fil
+Added doco for Responder->spawn
+Responder->spawn always returns true so that JAAS's factory doesn't complain
+
 Revision 1.11  2001/08/02 03:26:50  fil
 Added documentation.
