@@ -1,7 +1,7 @@
 package POE::Component::IKC::Server;
 
 ############################################################
-# $Id: Server.pm,v 1.11 2001/08/02 03:26:50 fil Exp $
+# $Id: Server.pm,v 1.13 2001/10/27 03:14:45 fil Exp $
 # Based on refserver.perl and preforkedserver.perl
 # Contributed by Artur Bergman <artur@vogon-solutions.com>
 # Revised for 0.06 by Rocco Caputo <troc@netrus.net>
@@ -27,9 +27,9 @@ require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_server);
-$VERSION = '0.1302';
+$VERSION = '0.1303';
 
-sub DEBUG { 1 }
+sub DEBUG { 0 }
 sub DEBUG_USR2 { 1 }
 BEGIN {
     # http://support.microsoft.com/support/kb/articles/Q150/5/37.asp
@@ -79,8 +79,10 @@ sub spawn
 sub _select_define
 {
     my($heap, $on)=@_;
+    $on||=0;
 
-    DEBUG and warn "_select_define";
+    DEBUG and 
+        warn "_select_define (on=$on)";
     my $state;
     my $err="possible redefinition of POE internals";
     $err="failure to bind to port" if $POE::VERSION <= 0.1005;
@@ -181,11 +183,13 @@ sub _start
     $heap->{"max connections"}=$params->{connections}||1;
 
     $heap->{'is a child'} = 0;          # change behavior for children
+    my $children=0;
     foreach (2..$params->{processes}) { # fork the initial set of children
-        $kernel->yield('fork');
+        $kernel->yield('fork', ($_ == $params->{processes}));
+        $children++;
     }
 
-    $kernel->delay('waste_time', 60);
+    $kernel->yield('waste_time', 60) unless $children;
     if($params->{babysit}) {
         $heap->{babysit}=$params->{babysit};
         delete($heap->{"proctable"});
@@ -209,6 +213,7 @@ sub waste_time
     return if $heap->{'is a child'};
 
     unless($heap->{'been told we are parent'}) {
+        warn "$$: Telling everyone we are the parent\n";
         $heap->{'been told we are parent'}=1;
         $kernel->signal($kernel, '__parent');
     }
@@ -473,7 +478,8 @@ sub accept
                 warn "$$: ************* Game over\n";
             $kernel->delay('waste_time');
             delete $heap->{wheel};
-            check_kernel($kernel);
+#            $kernel->post(IKC=>'shutdown');
+#            check_kernel($kernel);
 #            $kernel->yield('_stop');
         } else {
             DEBUG and 
@@ -491,7 +497,7 @@ sub accept
 # The server has been requested to fork, so fork already.
 sub fork 
 {
-    my ($kernel, $heap) = @_[KERNEL, HEAP];
+    my ($kernel, $heap, $last) = @_[KERNEL, HEAP, ARG0];
     # children should not honor this event
     # Note that the forked POE kernel might have these events in it already
     # this is unavoidable
@@ -549,6 +555,8 @@ sub fork
 
         DEBUG && print "$$: child server has been forked\n";
     }
+    $kernel->yield('waste_time') if $last;
+
     return;
 }
 
@@ -635,28 +643,30 @@ sub check_kernel
     my($kernel, $child, $signal)=@_;
     if(ref $kernel) {
         # 2 = KR_HANDLES
-        # 3 = KR_STATES
-        # 8 = KR_ALARMS
-        # 14 = KR_EXTRA_REFS
+        # 7 = KR_EVENTS
+        # 8 = KR_ALARMS (NO MORE!)
+        # 12 = KR_EXTRA_REFS
 
         # 0 = HND_HANDLE
         warn( "$$: ,----- Kernel Activity -----\n",  
-              "$$: | States : ", scalar(@{$kernel->[3]}), "\n",
-              "$$: | Alarms : ", scalar(@{$kernel->[8]}), "\n",
+              "$$: | States : ", scalar(@{$kernel->[7]}), " ",
+                            join( ', ', map {$_->[0]->ID."/$_->[2]"} 
+                                        @{$kernel->[7]}), "\n",
+#              "$$: | Alarms : ", scalar(@{$kernel->[8]}), "\n",
               "$$: | Files  : ", scalar(keys(%{$kernel->[2]})), "\n",
               "$$: |   `--> : ", join( ', ',
                                sort { $a <=> $b }
                                map { fileno($_->[0]) }
                                values(%{$kernel->[2]})
                              ),   "\n",
-              "$$: | Extra  : ${$kernel->[14]}\n",
+              "$$: | Extra  : ${$kernel->[12]}\n",
               "$$: `---------------------------\n",
          );
-        if($child) {
-            foreach my $q (@{$kernel->[8]}) {
-                warn "************ Alarm for ", join '/', @{$q->[0][2]{$q->[2]}};
-            }
-        }
+#        if($child) {
+#            foreach my $q (@{$kernel->[8]}) {
+#                warn "************ Alarm for ", join '/', @{$q->[0][2]{$q->[2]}};
+#            }
+#        }
     } else {
         warn "$kernel isn't a reference";
     }
